@@ -19,7 +19,7 @@ fieldhash my %my_id_generators => 'my_id_generators';
 fieldhash my %my_serializers   => 'my_serializers';
 
 our $errstr  = '';
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -279,9 +279,8 @@ sub flush
 
 sub get_my_drivers
 {
-	my($self) = @_;
-	my($path) = File::Spec -> catdir($INC{'Data/Session.pm'}, 'Driver');
-	$path     =~ s/.pm//;
+	my($self)	= @_;
+	my($path)	= $self -> _get_pm_path('Driver');
 
 	# Warning: Use sort map{} read_dir, not map{} sort read_dir. But, why?
 
@@ -299,9 +298,8 @@ sub get_my_drivers
 
 sub get_my_id_generators
 {
-	my($self) = @_;
-	my($path) = File::Spec -> catdir($INC{'Data/Session.pm'}, 'ID');
-	$path     =~ s/.pm//;
+	my($self)	= @_;
+	my($path)	= $self -> _get_pm_path('ID');
 
 	# Warning: Use sort map{} read_dir, not map{} sort read_dir. But, why?
 
@@ -319,9 +317,8 @@ sub get_my_id_generators
 
 sub get_my_serializers
 {
-	my($self) = @_;
-	my($path) = File::Spec -> catdir($INC{'Data/Session.pm'}, 'Serialize');
-	$path     =~ s/.pm//;
+	my($self)	= @_;
+	my($path)	= $self -> _get_pm_path('Serialize');
 
 	# Warning: Use sort map{} read_dir, not map{} sort read_dir. But, why?
 
@@ -337,6 +334,17 @@ sub get_my_serializers
 
 # -----------------------------------------------
 
+sub _get_pm_path
+{
+	my($self, $subdir)	= @_;
+	my($path)			= $INC{'Data/Session.pm'};
+	$path				=~ s/\.pm$//;
+
+	return File::Spec -> catdir($path, $subdir);
+}
+
+# -----------------------------------------------
+
 sub http_header
 {
 	my($self)   = shift;
@@ -1115,15 +1123,17 @@ Also, much can be gleaned from t/basic.t and t/Test.pm. See L</Test Code>.
 
 =head1 Description
 
-L<Data::Session> is typically used by a CGI script to preserve state data between runs of the script.
-This gives the end user the illusion that the script never exits.
+L<Data::Session> is typically used by a CGI script to preserve state data between runs of the
+script. This gives the end user the illusion that the script never exits.
 
-It can also be used to communicate between 2 scripts, as long as they agree beforehand what session id to use.
+It can also be used to communicate between 2 scripts, as long as they agree beforehand what session
+id to use.
 
-See L<Data::Session::CGISession> for an extended discussion of the design changes between L<Data::Session>
-and L<CGI::Session>.
+See L<Data::Session::CGISession> for an extended discussion of the design changes between
+L<Data::Session> and L<CGI::Session>.
 
-L<Data::Session> stores user data internally in a hashref, and the module reserves key names starting with '_'.
+L<Data::Session> stores user data internally in a hashref, and the module reserves key names
+starting with '_'.
 
 The current list of reserved keys is documented under L</flush()>.
 
@@ -1141,13 +1151,14 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
-But a warning: In some cases, setting them after this module has used the previous value, will have no effect.
-All such cases should be documented.
+But a warning: In some cases, setting them after this module has used the previous value, will have
+no effect. All such cases should be documented.
 
-Beginners understandably confused by the quantity of options should consult the L</Synopsis> for example code.
+Beginners understandably confused by the quantity of options should consult the L</Synopsis> for
+example code.
 
 The questions of combinations of options, and which option has priority over other options,
 are addressed in the section, L</Combinations of Options>.
@@ -1196,8 +1207,8 @@ Specifies a database handle to use to access the session table.
 
 This key is optional.
 
-However, if not specified, you must specify a value for 'data_source', and perhaps also 'username' and 'password',
-so that this module can create a database handle.
+However, if not specified, you must specify a value for 'data_source', and perhaps also 'username'
+and 'password', so that this module can create a database handle.
 
 If this module does create a database handle, it will also destroy it, whereas if you supply a database
 handle, you are responsible for destroying it.
@@ -1207,7 +1218,8 @@ handle, you are responsible for destroying it.
 Specifies that debugging should be turned on (1) or off (0) in L<Data::Session::File::Driver> and
 L<Data::Session::ID::AutoIncrement>.
 
-When debug is 1, $! is included in error messages, but because this reveals directory names, it is 0 by default.
+When debug is 1, $! is included in error messages, but because this reveals directory names, it is
+0 by default.
 
 This key is optional.
 
@@ -1215,8 +1227,8 @@ Default: 0.
 
 =item o directory => $string
 
-Specifies the directory in which session files are stored, when each session is stored in a separate file
-(by using 'driver:File ...' as the first component of the 'type').
+Specifies the directory in which session files are stored, when each session is stored in a separate
+file (by using 'driver:File ...' as the first component of the 'type').
 
 This key is optional.
 
@@ -1268,7 +1280,8 @@ Default: 'id'.
 
 =item o id_base => $integer
 
-Specifies the base from which to start ids when using the '... id:AutoIncrement ...' component in the 'type'.
+Specifies the base from which to start ids when using the '... id:AutoIncrement ...' component in
+the 'type'.
 
 Note: The first id returned by L<Data::Session::ID::AutoIncrement> will be id_base + id_step.
 So, if id_base is 1000 and id_step is 10, then the lowest id will be 1010.
@@ -1279,8 +1292,8 @@ Default: 0.
 
 =item o id_file => $file_path_and_name
 
-Specifies the file path and name in which to store the last used id, as calculated from id_base + id_step,
-when using the '... id:AutoIncrement ...' component in the 'type'.
+Specifies the file path and name in which to store the last used id, as calculated from C<id_base +
+id_step>, when using the '... id:AutoIncrement ...' component in the 'type'.
 
 This value must contain a path because the 'directory' option above is only used for session files
 (when using L<Data::Session::Driver::File>).
@@ -1291,7 +1304,8 @@ Default: File::Spec -> catdir(File::Spec -> tmpdir, 'data.session.id').
 
 =item o id_step => $integer
 
-Specifies the step size between ids when using the '... id:AutoIncrement ...' component of the 'type'.
+Specifies the step size between ids when using the '... id:AutoIncrement ...' component of the
+'type'.
 
 This key is optional.
 
@@ -1309,8 +1323,8 @@ Usage of 'name' is discussed in the sections L</Specifying an Id> and L</user_id
 
 =item o no_flock => $boolean
 
-Specifies (no_flock => 1) to not use flock() to obtain a lock on a session file before processing it,
-or (no_flock => 0) to use flock().
+Specifies (no_flock => 1) to not use flock() to obtain a lock on a session file before processing
+it, or (no_flock => 0) to use flock().
 
 This key is optional.
 
@@ -1357,7 +1371,8 @@ Default: '' (the empty string).
 Specifies that you're using a Postgres-specific column type of 'bytea' to hold the session data,
 in the session table.
 
-This key is optional, but see the section, L</Combinations of Options> for how it interacts with the pg_text key.
+This key is optional, but see the section, L</Combinations of Options> for how it interacts with
+the pg_text key.
 
 Default: 0.
 
@@ -1365,9 +1380,11 @@ Warning: Columns of type bytea can hold null characters (\x00), whereas columns
 
 =item o pg_text => $boolean
 
-Specifies that you're using a Postgres-specific column type of 'text' to hold the session data, in the session table.
+Specifies that you're using a Postgres-specific column type of 'text' to hold the session data, in
+the session table.
 
-This key is optional, but see the section, L</Combinations of Options> for how it interacts with the pg_bytea key.
+This key is optional, but see the section, L</Combinations of Options> for how it interacts with the
+pg_bytea key.
 
 Default: 0.
 
@@ -1472,8 +1489,8 @@ See L</dump([$heading])> for what happens when verbose is 2.
 
 See also L</Case-sensitive Options>.
 
-The default 'type' string is 'driver:File;id:MD5;serialize:DataDumper'. It consists of 3 optional components
-separated by semi-colons.
+The default 'type' string is 'driver:File;id:MD5;serialize:DataDumper'. It consists of 3 optional
+components separated by semi-colons.
 
 Each of those 3 components consists of 2 fields (a key and a value) separated by a colon.
 
@@ -1512,14 +1529,15 @@ See L<Data::Session::Driver::File>.
 
 =item o Memcached
 
-Use C<memcached> for storage. In this case, you must pass an object of type L<Cache::Memcached> to new() as the
-value of the 'cache' option.
+Use C<memcached> for storage. In this case, you must pass an object of type L<Cache::Memcached> to
+new() as the value of the 'cache' option.
 
 See L<Data::Session::Driver::Memcached>.
 
 =item o mysql
 
-This says each session is stored in a separate row of a database table using the L<DBD::mysql> database server.
+This says each session is stored in a separate row of a database table using the L<DBD::mysql>
+database server.
 
 These rows have a unique primary id equal to the session id.
 
@@ -1527,7 +1545,8 @@ See L<Data::Session::Driver::mysql>.
 
 =item o ODBC
 
-This says each session is stored in a separate row of a database table using the L<DBD::ODBC> database connector.
+This says each session is stored in a separate row of a database table using the L<DBD::ODBC>
+database connector.
 
 These rows have a unique primary id equal to the session id.
 
@@ -1535,7 +1554,8 @@ See L<Data::Session::Driver::ODBC>.
 
 =item o Oracle
 
-This says each session is stored in a separate row of a database table using the L<DBD::Oracle> database server.
+This says each session is stored in a separate row of a database table using the L<DBD::Oracle>
+database server.
 
 These rows have a unique primary id equal to the session id.
 
@@ -1543,7 +1563,8 @@ See L<Data::Session::Driver::Oracle>.
 
 =item o Pg
 
-This says each session is stored in a separate row of a database table using the L<DBD::Pg> database server.
+This says each session is stored in a separate row of a database table using the L<DBD::Pg> database
+server.
 
 These rows have a unique primary id equal to the session id.
 
@@ -1551,7 +1572,8 @@ See L<Data::Session::Driver::Pg>.
 
 =item o SQLite
 
-This says each session is stored in a separate row of a database table using the SQLite database server.
+This says each session is stored in a separate row of a database table using the SQLite database
+server.
 
 These rows have a unique primary id equal to the session id.
 
@@ -1576,13 +1598,14 @@ and the last-used id is stored in the file name given by the 'id_file' option to
 
 This file name must include a path, since the 'directory' option to new() is I<not> used here.
 
-When a new id is required, the value in the file is incremented by the value of the 'id_step' option to new(),
-with the new value both written back to the file and returned as the new session id.
+When a new id is required, the value in the file is incremented by the value of the 'id_step' option
+to new(), with the new value both written back to the file and returned as the new session id.
 
-The default value of id_base is 0, and the default value of id_step is 1. Together, the first id available
-as a session id is id_base + id_step = 1.
+The default value of id_base is 0, and the default value of id_step is 1. Together, the first id
+available as a session id is id_base + id_step = 1.
 
-The sequence starts when the module cannot find the given file, or when its contents are not numeric.
+The sequence starts when the module cannot find the given file, or when its contents are not
+numeric.
 
 See L<Data::Session::ID::AutoIncrement>.
 
@@ -1615,7 +1638,8 @@ See L<Data::Session::ID::SHA512>.
 This says that the id passed in to new(), as the value of the 'id' option, will be used as the
 session id for every session.
 
-Of course, this id must have a true value. L<Data::Session> dies on all values Perl regards as false.
+Of course, this id must have a true value. L<Data::Session> dies on all values Perl regards as
+false.
 
 See L<Data::Session::ID::Static>.
 
@@ -1639,7 +1663,8 @@ See L<Data::Session::ID::UUID36>.
 
 =item o UUID64
 
-This says ids are to be generated by L<Data::UUID>, to generate a 24 (sic) byte long, base-64 encoded, UUID.
+This says ids are to be generated by L<Data::UUID>, to generate a 24 (sic) byte long, base-64
+encoded, UUID.
 
 See L<Data::Session::ID::UUID64>.
 
@@ -1649,8 +1674,8 @@ See scripts/digest.pl which prints the length of each type of digest.
 
 =item o serialize
 
-The specifies what type of mechanism you wish to use to convert the in-memory session data into a form
-appropriate for your chosen storage type.
+The specifies what type of mechanism you wish to use to convert the in-memory session data into a
+form appropriate for your chosen storage type.
 
 Values for 'serialize':
 
@@ -1680,7 +1705,8 @@ Use L<Storable> to freeze/thaw sessions.
 
 See L<Data::Session::Serialize::Storable>.
 
-Warning: Storable should be avoided until this problem is fixed: http://rt.cpan.org/Public/Bug/Display.html?id=36087
+Warning: Storable should be avoided until this problem is fixed:
+L<http://rt.cpan.org/Public/Bug/Display.html?id=36087>.
 
 =item o YAML
 
@@ -1694,7 +1720,8 @@ See L<Data::Session::Serialize::YAML>.
 
 =head3 Case-sensitive Options
 
-Just to emphasize: The names of drivers, etc follow the DBD::* (or similar) style of case-sensitivity.
+Just to emphasize: The names of drivers, etc follow the DBD::* (or similar) style of
+case-sensitivity.
 
 The following classes for drivers, id generators and serializers, are shipped with this package.
 
@@ -1712,7 +1739,8 @@ And yes, the module uses L<BerkeleyDB> and not L<DB_File>.
 
 =item o L<Data::Session::Driver::Memcached>
 
-This name comes from L<Cache::Memcached> even though the external program you run is called memcached.
+This name comes from L<Cache::Memcached> even though the external program you run is called
+memcached.
 
 =item o L<Data::Session::Driver::mysql>
 
@@ -1764,7 +1792,8 @@ Serializers:
 
 =item o L<Data::Session::Serialize::Storable>
 
-Warning: Storable should be avoided until this problem is fixed: http://rt.cpan.org/Public/Bug/Display.html?id=36087
+Warning: Storable should be avoided until this problem is fixed:
+L<http://rt.cpan.org/Public/Bug/Display.html?id=36087>
 
 =item o L<Data::Session::Serialize::YAML>
 
@@ -1819,22 +1848,25 @@ See also L</Specifying Session Options>, for options-related combinations.
 
 =item o dbh
 
-If you don't specify a value for the 'dbh' key, this module must create a database handle in those cases
-when you specify a database driver of some sort in the value for 'type'.
+If you don't specify a value for the 'dbh' key, this module must create a database handle in those
+cases when you specify a database driver of some sort in the value for 'type'.
 
-To create that handle, we needs a value for 'data_source', and that in turn may require values for 'username'
-and 'password'.
+To create that handle, we needs a value for 'data_source', and that in turn may require values for
+'username' and 'password'.
 
-When using SQLite, just specify a value for 'data_source'. The default values for 'username' and 'password' -
-empty strings - will work.
+When using SQLite, just specify a value for 'data_source'. The default values for 'username' and
+'password' - empty strings - will work.
 
 =item o file_name and id_file
 
-When using new(type => 'driver:File;id:AutoIncrement;...'), then file_name is ignored and id_file is used.
+When using new(type => 'driver:File;id:AutoIncrement;...'), then file_name is ignored and id_file is
+used.
 
-If id_file is not supplied, it defaults to File::Spec -> catdir(File::Spec -> tmpdir, 'data.session.id').
+If id_file is not supplied, it defaults to File::Spec -> catdir(File::Spec -> tmpdir,
+'data.session.id').
 
-When using new(type => 'driver:File;id:<Not AutoIncrement>;...'), then id_file is ignored and file_name is used.
+When using new(type => 'driver:File;id:<Not AutoIncrement>;...'), then id_file is ignored and
+file_name is used.
 
 If file_name is not supplied, it defaults to 'cgisess_%s'. Note the mandatory %s.
 
@@ -1882,7 +1914,8 @@ See L</expired()>.
 
 =back
 
-This is used when the session is loaded, when you call L</http_header([@arg])>, and by scripts/expire.pl.
+This is used when the session is loaded, when you call L</http_header([@arg])>, and by
+scripts/expire.pl.
 
 =head2 clear([$name])
 
@@ -1890,11 +1923,13 @@ The [] indicates an optional parameter.
 
 Returns 1.
 
-Specifies that you wish to delete parameters stored in the session, i.e. stored by previous calls to param().
+Specifies that you wish to delete parameters stored in the session, i.e. stored by previous calls to
+param().
 
 $name is a parameter name or an arrayref of parameter names.
 
-If $name is not specified, it is set to the list of all unreserved keys (parameter names) in the session.
+If $name is not specified, it is set to the list of all unreserved keys (parameter names) in the
+session.
 
 See L</param([@arg])> for details.
 
@@ -1906,7 +1941,8 @@ Returns a cookie, or '' (the empty string) if the query object does not have a c
 
 Use the @arg parameter to pass any extra parameters to the query object's cookie() method.
 
-Warning: Parameters which are handled by L<Data::Session>, and hence should I<not> be passed in, are:
+Warning: Parameters which are handled by L<Data::Session>, and hence should I<not> be passed in,
+are:
 
 =over 4
 
@@ -1999,10 +2035,11 @@ See also L</atime()>, L</ctime()> and L</ptime()>.
 
 The [] indicates an optional parameter.
 
-Specifies that you wish to set or retrieve the session's expiry time, or set the expiry times of session
-parameters.
+Specifies that you wish to set or retrieve the session's expiry time, or set the expiry times of
+session parameters.
 
-Integer time values ($time below) are assumed to be seconds. The value may be positive or 0 or negative.
+Integer time values ($time below) are assumed to be seconds. The value may be positive or 0 or
+negative.
 
 These expiry times are relative to the session's last access time, not the session's creation time.
 
@@ -2012,12 +2049,14 @@ This affects users of L<Cache::Memcached>. See below and L<Data::Session::Driver
 
 When a session expires, it is deleted from storage. See L</delete()> for details.
 
-The test for whether or not a session has expired only takes place when a session is loaded from storage.
+The test for whether or not a session has expired only takes place when a session is loaded from
+storage.
 
 When a session parameter expires, it is deleted from the session object. See L</clear([$name])>
 for details.
 
-The test for whether or not a session parameter has expired only takes place when a session is loaded from storage.
+The test for whether or not a session parameter has expired only takes place when a session is
+loaded from storage.
 
 =over 4
 
@@ -2053,13 +2092,15 @@ so L</validate_time($time)> is available to you too.
 
 If setting a time like this, expire($time) returns 1.
 
-Note: The time set here is passed as the 3rd parameter to the storage driver's store() method (for all
-types of storage), and from there as the 3rd parameter to the set() method of L<Cache::Memcached>.
-Of course, this doesn't happen immediately - it only happens when the session is saved.
+Note: The time set here is passed as the 3rd parameter to the storage driver's store() method (for
+all types of storage), and from there as the 3rd parameter to the set() method of
+L<Cache::Memcached>. Of course, this doesn't happen immediately - it only happens when the session
+is saved.
 
 =item o $session -> expire($key_1 => $time_1[, $key_2 => $time_2...])
 
-Use $session -> expire($key_1 => $time_1[, $key_2 => $time_2...]) to set the expiry times of session parameters.
+Use $session -> expire($key_1 => $time_1[, $key_2 => $time_2...]) to set the expiry times of
+session parameters.
 
 =back
 
@@ -2092,8 +2133,8 @@ If you have previously called delete(), the call to flush() is ignored.
 
 If the object has not been modified, the call to flush() is ignored.
 
-Warning: With persistent environments, you object may never go out of scope that way you think it does.
-See L</Trouble with Exiting> for details.
+Warning: With persistent environments, you object may never go out of scope that way you think it
+does.See L</Trouble with Exiting> for details.
 
 These reserved session parameters are included in what's written to storage:
 
@@ -2113,7 +2154,8 @@ The session's expiry time.
 
 A time of 0 means there is no expiry time.
 
-This affect users of L<Cache::Memcached>. See L</expire([@arg])> and L<Data::Session::Driver::Memcached>.
+This affect users of L<Cache::Memcached>. See L</expire([@arg])> and
+L<Data::Session::Driver::Memcached>.
 
 =item o _SESSION_ID
 
@@ -2129,19 +2171,21 @@ A hashref of session parameter expiry times.
 
 The [] indicate an optional parameter.
 
-Returns a HTTP header. This means it does I<not> print the header. You have to do that, when appropriate.
+Returns a HTTP header. This means it does I<not> print the header. You have to do that, when
+appropriate.
 
 Unlike L<CGI::Session>, L<Data::Session> does I<not> force the document type to be 'text/html'.
 
-You must pass in a document type to http_header(), as $session -> http_header('-type' => 'text/html'),
-or use the query object's default.
+You must pass in a document type to http_header(), as
+C<< $session -> http_header('-type' => 'text/html') >>, or use the query object's default.
 
 Both L<CGI> and L<CGI::Simple> default to 'text/html'.
 
 L<Data::Session> handles the case where the query object does not have a cookie() method, by calling
 $session -> cookie() to generate either a cookie, or '' (the empty string).
 
-The @arg parameter, if any, is passed to the query object's header() method, after the cookie parameter, if any.
+The @arg parameter, if any, is passed to the query object's header() method, after the cookie
+parameter, if any.
 
 =head2 id()
 
@@ -2209,7 +2253,8 @@ You can call is_new() to tell the difference between these 2 cases.
 Returns a Boolean (0/1) indicating whether or not the session's parameters have been modified.
 
 However, changing a value from one form of not-defined, e.g. undef, to another form of not-defined,
-e.g. 0, is ignored, meaning the modified flag is not set. In such cases, you could set the flag youself.
+e.g. 0, is ignored, meaning the modified flag is not set. In such cases, you could set the flag
+yourself.
 
 Note: Loading a session from storage changes the session's last access time, which means the session
 has been modified.
@@ -2221,7 +2266,8 @@ modified flag with $session -> modified(0).
 
 The [] indicates an optional parameter.
 
-Specifies that you wish to retrieve data stored in the session, or you wish to store data in the session.
+Specifies that you wish to retrieve data stored in the session, or you wish to store data in the
+session.
 
 Data is stored in the session object as in a hash, via a set of $key => $value relationships.
 
@@ -2231,8 +2277,8 @@ If storing data, param() returns 1.
 
 The values stored in the session may be undef.
 
-Note: If the value being stored is the same as the pre-existing value, the value in the session is not updated,
-which means the last access time does not change.
+Note: If the value being stored is the same as the pre-existing value, the value in the session is
+not updated, which means the last access time does not change.
 
 Use $session -> param() to return a sorted list of all keys.
 
@@ -2265,7 +2311,8 @@ L</load_param([$q][, $name])> performs the opposite operation.
 $q is a query object, and $name is a parameter name or an arrayref of names.
 
 If the query object is not specified, generates one by calling $session -> load_query_class,
-and stores it in the internal 'query' attribute. This means you can retrieve it with $session -> query.
+and stores it in the internal 'query' attribute. This means you can retrieve it with
+$session -> query.
 
 If you don't provide $q, use undef, don't just omit the parameter.
 
@@ -2277,10 +2324,11 @@ If $name is not specified, copies all parameters.
 
 Returns 1.
 
-Specifies that you want the $sub called for each session id found in storage, with one (1) id as the only
-parameter in each call.
+Specifies that you want the $sub called for each session id found in storage, with one (1) id as
+the only parameter in each call.
 
-Note: traverse($sub) does not load the sessions, and hence has no effect on the session's last access time.
+Note: traverse($sub) does not load the sessions, and hence has no effect on the session's last
+access time.
 
 See scripts/expire.pl.
 
@@ -2307,7 +2355,8 @@ If the query object does not support the cookie method, just call $self -> query
 
 Return any id found, or 0.
 
-Note: The name of the cookie, and the name of the CGI form field, is passed to new() by the 'name' option.
+Note: The name of the cookie, and the name of the CGI form field, is passed to new() by the 'name'
+option.
 
 =back
 
@@ -2337,9 +2386,11 @@ or you can edit t/bulk.ini as desired, and pass it in like this:
 
 	perl -Ilib t/basic.t t/bulk.ini
 
-Simple instructions for installing L<BerkeleyDB> (Oracle and Perl) are in L<Data::Session::Driver::Berkeley>.
+Simple instructions for installing L<BerkeleyDB> (Oracle and Perl) are in
+L<Data::Session::Driver::Berkeley>.
 
-Simple instructions for installing L<Cache::Memcached> and memcached are in L<Data::Session::Driver::Memcached>.
+Simple instructions for installing L<Cache::Memcached> and memcached are in
+L<Data::Session::Driver::Memcached>.
 
 =head1 FAQ
 
@@ -2361,15 +2412,15 @@ Then inside your sub-class's methods, this works:
 
 	my($value) = $self -> param('a_key');
 
-because those 2 modules each implement a method called I<param()>. Basically, you're storing a value (via
-'param') inside $self.
+because those 2 modules each implement a method called I<param()>. Basically, you're storing a value
+(via 'param') inside $self.
 
 But when you store an object of type Data::Session using I<param()>, it looks like this:
 
 	$self -> param(session => Data::Session -> new(...) );
 
-Now, Data::Session itself I<also> implements a method called I<param()>. So, to store something in the
-session (but not in $self), you must do:
+Now, Data::Session itself I<also> implements a method called I<param()>. So, to store something in
+the session (but not in $self), you must do:
 
 	$self -> param('session') -> param(a_key => 'a_value');
 
@@ -2382,12 +2433,12 @@ $self -> param('session') both have I<param()> methods.
 
 =item o 2: How exactly should a L<CGI> script save a session?
 
-The first example in the Synopsis shows a very simple L<CGI> script doing the right thing by calling
-I<flush()> just before it exits.
+The first example in the Synopsis shows a very simple L<CGI> script doing the right thing by
+calling I<flush()> just before it exits.
 
-Alternately, if you sub-class L<CGI::Snapp>, the call to I<flush()> is best placed in your I<teardown()>
-method, which is where you override L<CGI::Snapp/teardown()>. The point here is that your I<teardown()>
-is called automatically at the end of each run mode.
+Alternately, if you sub-class L<CGI::Snapp>, the call to I<flush()> is best placed in your
+I<teardown()> method, which is where you override L<CGI::Snapp/teardown()>. The point here is that
+your I<teardown()> is called automatically at the end of each run mode.
 
 This important matter is also discussed in L</General Questions> below.
 
@@ -2405,12 +2456,12 @@ This will fail:
 
 Likewise for an array instead of a hash.
 
-But why? Because the part 'param(my_hash => %my_hash)' is basically assigning a list (%my_hash) to a
-scalar (my_hash). Hence, only 1 element of the list (the 'first' key in some unknown order) will be
-assigned.
+But why? Because the part 'param(my_hash => %my_hash)' is basically assigning a list (%my_hash) to
+a scalar (my_hash). Hence, only 1 element of the list (the 'first' key in some unknown order) will
+be assigned.
 
-So, when you try to restore the hash with 'my(%my_hash) ...', all you'll get back is a scalar, which will
-generate the classic error message 'Odd number of elements in hash assignment...'.
+So, when you try to restore the hash with 'my(%my_hash) ...', all you'll get back is a scalar, which
+will generate the classic error message 'Odd number of elements in hash assignment...'.
 
 The solution is to use arrayrefs and hashrefs:
 
@@ -2436,21 +2487,24 @@ Likewise for an array:
 
 =item o My sessions are not getting written to disk!
 
-This is because you haven't stored anything in them. You're probably thinking sessions are saved just because they exist.
+This is because you haven't stored anything in them. You're probably thinking sessions are saved
+just because they exist.
 
-Actually, sessions are only saved if they have at least 1 parameter set. The session id and access/etc times are
-not enough to trigger saving.
+Actually, sessions are only saved if they have at least 1 parameter set. The session id and
+access/etc times are not enough to trigger saving.
 
-Just do something like $session -> param(ok => 1); if you want a session saved just to indicate it exists. Code like this
-sets the modified flag on the session, so that flush() actually does the save.
+Just do something like $session -> param(ok => 1); if you want a session saved just to indicate it
+exists. Code like this sets the modified flag on the session, so that flush() actually does the
+save.
 
-Also, see L</Trouble with Exiting>, below, to understand why flush() must be called explicitly in persistent environments.
+Also, see L</Trouble with Exiting>, below, to understand why flush() must be called explicitly in
+persistent environments.
 
 =item o Why don't the test scripts use L<Test::Database>?
 
-I decided to circumvent it by using L<DBIx::Admin::DSNManager> and adopting the wonders of nested testing.
-But, since V 1.11, I've replaced that module with L<Config::Tiny>, to reduce dependencies, and hence to make it easier
-to get L<Data::Session> into Debian.
+I decided to circumvent it by using L<DBIx::Admin::DSNManager> and adopting the wonders of nested
+testing. But, since V 1.11, I've replaced that module with L<Config::Tiny>, to reduce dependencies,
+and hence to make it easier to get L<Data::Session> into Debian.
 
 See t/basic.t, and in particular this line: subtest $driver => sub.
 
@@ -2493,14 +2547,14 @@ However, when methods detect errors they die, so after successful object constru
 
 =head2 Trouble with Exiting
 
-If the session object's clean-up code is called, in DESTROY(), the session data is automatically flushed to
-storage (except when it's been deleted, or has not been modified).
+If the session object's clean-up code is called, in DESTROY(), the session data is automatically
+flushed to storage (except when it's been deleted, or has not been modified).
 
-However, as explained below, there can be problems with your code (i.e. not with L<Data::Session>) such that
-this clean-up code is not called, or, if called, it cannot perform as expected.
+However, as explained below, there can be problems with your code (i.e. not with L<Data::Session>)
+such that this clean-up code is not called, or, if called, it cannot perform as expected.
 
-The general guideline, then, is that you should explicitly call C<flush()> on the session object before your
-program exits.
+The general guideline, then, is that you should explicitly call C<flush()> on the session object
+before your program exits.
 
 Common traps for beginners:
 
@@ -2512,29 +2566,31 @@ If your code creates an object of type L<CGI> or similar, but you don't pass tha
 L<Data::Session> via the 'query' parameter to new(), this module will create one for you,
 which can be very confusing.
 
-The solution is to always create such a object yourself, and to always pass that into L<Data::Session>.
+The solution is to always create such a object yourself, and to always pass that into
+L<Data::Session>.
 
-In the case that the user of a CGI script runs your code for the first time, there will be no session id,
-either from a cookie or from a form field.
+In the case that the user of a CGI script runs your code for the first time, there will be no
+session id, either from a cookie or from a form field.
 
 In such a case, L<Data::Session> will do what you expect, which is to generate a session id.
 
 =item o Letting your database handle go out of scope too early
 
-When your script is exiting, and you're trying to save session data to storage via a database handle,
-the save will fail if the handle goes out of scope before the session data is flushed to storage.
+When your script is exiting, and you're trying to save session data to storage via a database
+handle, the save will fail if the handle goes out of scope before the session data is flushed to
+storage.
 
 So, don't do that.
 
 =item o Assuming your session object goes out of scope when it doesn't
 
-In persistent environments such as L<Plack>, FastCGI and mod_perl, your code exits as expected, but the
-session object does not go out of scope in the normal way.
+In persistent environments such as L<Plack>, FastCGI and mod_perl, your code exits as expected, but
+the session object does not go out of scope in the normal way.
 
 In cases like this, it is mandatory for you to call flush() on the session object before your
 code exits, since persistent environments operate in such a way that the session object's clean-up
-code does not get called. This means that flush() is not called automatically by DESTROY() as you would expect,
-because DESTROY() is not being called.
+code does not get called. This means that flush() is not called automatically by DESTROY() as you
+would expect, because DESTROY() is not being called.
 
 =item o Creating circular references anywhere in your code
 
@@ -2553,16 +2609,17 @@ might affect program exit logic.
 
 =head2 Trouble with IDs
 
-The module uses code like if (! $self -> id), which means ids must be (Perl) true values, so undef, 0 and ''
-will not work.
+The module uses code like if (! $self -> id), which means ids must be (Perl) true values, so undef,
+0 and '' will not work.
 
 =head2 Trouble with UUID16
 
 While testing with UUID16 as the id generator, I got this message:
 ... invalid byte sequence for encoding "UTF8" ...
 
-That's because when I create a database (in Postgres) I use "create database d_name owner d_owner encoding 'UTF8';"
-and UUID16 simply produces a 16 byte binary value, which is not guaranteed to be or contain a valid UTF8 character.
+That's because when I create a database (in Postgres) I use "create database d_name owner d_owner
+encoding 'UTF8';" and UUID16 simply produces a 16 byte binary value, which is not guaranteed to be
+or contain a valid UTF8 character.
 
 This also means you should never try to use 'driver:File;id:UUID16 ...', since the ids generated by
 this module would rarely if ever be valid as a part of a file name.
@@ -2580,6 +2637,10 @@ So, don't do that.
 
 Version numbers < 1.00 represent development versions. From 1.00 up, they are production versions.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/Data-Session.git>
+
 =head1 Support
 
 Log a bug on RT: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Session>.
@@ -2591,7 +2652,8 @@ See L<http://www.erlbaum.net/mailman/listinfo/cgiapp> for details.
 
 =head1 Thanks
 
-Many thanks are due to all the people who contributed to both L<Apache::Session> and L<CGI::Session>.
+Many thanks are due to all the people who contributed to both L<Apache::Session> and
+L<CGI::Session>.
 
 Likewise, many thanks to the implementors of nesting testing. See L<Test::Simple>.
 
