@@ -1,6 +1,6 @@
 package Data::Session::CGISession;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -14,36 +14,41 @@ L<Data::Session> - A persistent session manager
 
 =head1 The Design of Data::Session, contrasted with CGI::Session
 
-For background, read the docs (including the Changes files) and bug reports for both L<Apache::Session>
-and L<CGI::Session>.
+For background, read the docs (including the Changes files) and bug reports for both
+L<Apache::Session> and L<CGI::Session>.
 
-The interface to L<Data::Session> is not quite compatible with that of L<CGI::Session>, hence the new namespace.
+The interface to L<Data::Session> is not quite compatible with that of L<CGI::Session>, hence the
+new namespace.
 
-The purpose of L<Data::Session> is to be a brand-new alternative to both L<Apache::Session> and L<CGI::Session>.
+The purpose of L<Data::Session> is to be a brand-new alternative to both L<Apache::Session> and
+L<CGI::Session>.
 
 =head1 Aliases for Method Names
 
 Aliases for method names are not supported.
 
-In L<CGI::Session>, methods etime() and expires() were aliased to expire(). This is not supported in L<Data::Session>.
+In L<CGI::Session>, methods etime() and expires() were aliased to expire(). This is not supported
+in L<Data::Session>.
 
 L<Data::Session> does have an etime() method, L<Data::Session/Method: etime()>, which is different.
 
-In L<CGI::Session>, method header() was aliased to http_header(). Only the latter method is supported in
-L<Data::Session>. See L</Method: cookie()> and L</Method: http_header([@arg])>.
+In L<CGI::Session>, method header() was aliased to http_header(). Only the latter method is
+supported in L<Data::Session>. See L</Method: cookie()> and L</Method: http_header([@arg])>.
 
-In L<CGI::Session>, id generators had a method generate_id() aliased to generate(). This is not supported in
-L<Data::Session>.
+In L<CGI::Session>, id generators had a method generate_id() aliased to generate(). This is not
+supported in L<Data::Session>.
 
-In L<CGI::Session>, method param_dataref() was aliased to dataref(). Neither of these methods is supported in
-L<Data::Session>. If you want to access the session data, use my($hashref) = $session -> session.
+In L<CGI::Session>, method param_dataref() was aliased to dataref(). Neither of these methods is
+supported in L<Data::Session>. If you want to access the session data, use
+my($hashref) = $session -> session.
 
 =head1 Backwards-compatibility
 
-This topic is sometimes used as a form of coercion, which is unacceptable, and sometimes leads to a crippled design.
+This topic is sometimes used as a form of coercion, which is unacceptable, and sometimes leads to
+a crippled design.
 
-So, by design, L<Data::Session> is not I<exactly> backwards-compatible with L<CGI::Session>, but does
-retain it's major features:
+So, by design, L<Data::Session> is not I<exactly> backwards-compatible with L<CGI::Session>, but
+does retain it's major features:
 
 =over 4
 
@@ -84,8 +89,8 @@ which means if it is not needed it is not created.
 
 Calling methods on the class is not supported. You must always create an object.
 
-The reason for this is to ensure every method call, without exception, has access to the per-object data
-supplied by you, or by default, in the call to new().
+The reason for this is to ensure every method call, without exception, has access to the per-object
+data supplied by you, or by default, in the call to new().
 
 =head1 The type of the Data::Session object
 
@@ -105,8 +110,8 @@ Nevertheless, lower-cased input will be accepted. Such input is converted to the
 This affects the names of various sub-classes. See L</ID Generators>, L</Serialization Drivers> and
 L</Storage Drivers>.
 
-For example, driver:pg is now driver:Pg, which actually means L<Data::Session::Driver::Pg>, based on the
-class name L<DBD::Pg>.
+For example, driver:pg is now driver:Pg, which actually means L<Data::Session::Driver::Pg>, based on
+the class name L<DBD::Pg>.
 
 =head1 Exceptions
 
@@ -167,11 +172,11 @@ So, neither L<Mouse> nor L<Moose>, nor any other such class helper, is used.
 
 =head1 Method: cookie()
 
-Forcing the query object to have a cookie method is not supported. You may now use a query class which does not
-provide a cookie method.
+Forcing the query object to have a cookie method is not supported. You may now use a query class
+which does not provide a cookie method.
 
-The logic of checking the cookie (if any) first (i.e. before checking for a form field of the same name)
-is supported.
+The logic of checking the cookie (if any) first (i.e. before checking for a form field of the same
+name) is supported.
 
 See L</Method: http_header([@arg])>.
 
@@ -179,15 +184,17 @@ See L</Method: http_header([@arg])>.
 
 The [] indicate an optional parameter.
 
-Returns a HTTP header. This means it does not print the header. You have to do that, when appropriate.
+Returns a HTTP header. This means it does not print the header. You have to do that, when
+appropriate.
 
-Forcing the document type to be 'text/html' when calling http_header() is not supported. You must pass
-in a document type to http_header(), as $session -> http_header('-type' => 'text/html'), or use the query
-object's default. Both L<CGI> and L<CGI::Simple> default to 'text/html'.
+Forcing the document type to be 'text/html' when calling http_header() is not supported. You must
+pass in a document type to http_header(), as $session -> http_header('-type' => 'text/html'), or
+use the query object's default. Both L<CGI> and L<CGI::Simple> default to 'text/html'.
 
 L<Data::Session> handles the case where the query object does not have a cookie() method.
 
-The @arg parameter, if any, is passed to the query object's header() method, after the cookie parameter, if any.
+The @arg parameter, if any, is passed to the query object's header() method, after the cookie
+parameter, if any.
 
 =head1 Method: load()
 
@@ -297,8 +304,8 @@ See L<Data::Session/Specifying an Id> for details.
 
 =head1 Session modification
 
-L<CGI::Session> tracks calls to param() to set a flag if the object is modified, so as to avoid writing
-the session to disk if nothing has been modified.
+L<CGI::Session> tracks calls to param() to set a flag if the object is modified, so as to avoid
+writing the session to disk if nothing has been modified.
 
 This includes checking if setting a param's value to the value it already has.
 
@@ -366,7 +373,8 @@ Hashref: Expiry times of parameters.
 
 =back
 
-L<Data::Session> stores user data internally in a hashref, and the module reserves keys starting with '_'.
+L<Data::Session> stores user data internally in a hashref, and the module reserves keys starting
+with '_'.
 
 Of course, it has a whole set of methods to manage state.
 
