@@ -11,7 +11,7 @@ use Hash::FieldHash ':all';
 
 use Try::Tiny;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -119,13 +119,15 @@ See L<Data::Session> for details.
 
 =head1 Description
 
-L<Data::Session::Driver::BerkeleyDB> allows L<Data::Session> to manipulate sessions via L<BerkeleyDB>.
+L<Data::Session::Driver::BerkeleyDB> allows L<Data::Session> to manipulate sessions via
+L<BerkeleyDB>.
 
 To use this module do both of these:
 
 =over 4
 
-=item o Specify a driver of type BerkeleyDB, as Data::Session -> new(type => 'driver:BerkeleyDB ...')
+=item o Specify a driver of type BerkeleyDB, as
+Data::Session -> new(type => 'driver:BerkeleyDB ...')
 
 =item o Specify a cache object of type L<BerkeleyDB> as Data::Session -> new(cache => $object)
 
@@ -148,8 +150,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -206,8 +208,8 @@ This result is a Boolean value indicating 1 => success or 0 => failure.
 
 =head1 Method: traverse()
 
-Retrieves all ids via a cursor, and for each id calls the supplied subroutine with the id as the only
-parameter.
+Retrieves all ids via a cursor, and for each id calls the supplied subroutine with the id as the
+only parameter.
 
 The database is not locked during this process.
 
@@ -215,7 +217,8 @@ Returns 1.
 
 =head1 Installing BerkeleyDB
 
-	Get Oracle's BerkeleyDB from http://www.oracle.com/technetwork/database/berkeleydb/overview/index.html
+	Get Oracle's BerkeleyDB from
+	http://www.oracle.com/technetwork/database/berkeleydb/overview/index.html
 	I used V 5.1.19
 	tar xvzf db-5.1.19.tar.gz
 	cd db-5.1.19/build_unix
