@@ -14,7 +14,7 @@ use Hash::FieldHash ':all';
 
 use Try::Tiny;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -242,8 +242,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -252,7 +252,8 @@ at any time.
 Specifies that debugging should be turned on (1) or off (0) in L<Data::Session::File::Driver> and
 L<Data::Session::ID::AutoIncrement>.
 
-When debug is 1, $! is included in error messages, but because this reveals directory names, it is 0 by default.
+When debug is 1, $! is included in error messages, but because this reveals directory names, it is 0
+by default.
 
 This key is optional.
 
@@ -270,8 +271,8 @@ This key is optional.
 
 =item o file_name => $string_containing_%s
 
-Specifies the pattern to use for session file names. It must contain 1 '%s', which will be replaced by the
-session id before the pattern is used as a file name.
+Specifies the pattern to use for session file names. It must contain 1 '%s', which will be replaced
+by the session id before the pattern is used as a file name.
 
 This key is normally passed in as Data::Session -> new(file_name => $string_containing_%s).
 
@@ -281,8 +282,8 @@ This key is optional.
 
 =item o no_flock => $boolean
 
-Specifies (no_flock => 1) to not use flock() to obtain a lock on a session file before processing it,
-or (no_flock => 0) to use flock().
+Specifies (no_flock => 1) to not use flock() to obtain a lock on a session file before processing
+it, or (no_flock => 0) to use flock().
 
 This key is normally passed in as Data::Session -> new(no_flock => $boolean).
 
@@ -351,8 +352,8 @@ Returns 1 if it succeeds, and dies if it can't.
 
 =head1 Method: traverse($sub)
 
-Retrieves all ids via their file names, and for each id calls the supplied subroutine with the id as the only
-parameter.
+Retrieves all ids via their file names, and for each id calls the supplied subroutine with the id as
+the only parameter.
 
 Returns 1.
 
