@@ -9,7 +9,7 @@ use Hash::FieldHash ':all';
 
 use Try::Tiny;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -93,7 +93,8 @@ See L<Data::Session> for details.
 
 =head1 Description
 
-L<Data::Session::Driver::Memcached> allows L<Data::Session> to manipulate sessions L<Cache::Memcached>.
+L<Data::Session::Driver::Memcached> allows L<Data::Session> to manipulate sessions
+L<Cache::Memcached>.
 
 To use this module do both of these:
 
@@ -120,8 +121,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -179,8 +180,8 @@ set() method to change 0 to 'never'.
 
 =head1 Method: traverse()
 
-There is no mechanism (apart from memcached's debug code) to get a list of all keys in a cache managed
-by memcached, so there is no way to traverse them via this module.
+There is no mechanism (apart from memcached's debug code) to get a list of all keys in a cache
+managed by memcached, so there is no way to traverse them via this module.
 
 Returns 1.
 
