@@ -11,7 +11,7 @@ use Hash::FieldHash ':all';
 
 use Try::Tiny;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -166,8 +166,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -183,8 +183,8 @@ This key is optional.
 
 =item o data_source => $string
 
-Specifies the data source (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the data source (as used by
+DBI -> connect($data_source, $username, $password, $data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(data_source => $string).
 
@@ -194,8 +194,8 @@ This key is optional, as long as a value is supplied for 'dbh'.
 
 =item o data_source_attr => $hashref
 
-Specifies the attributes (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the attributes (as used by
+DBI -> connect($data_source, $username, $password, $data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(data_source_attr => $hashref).
 
@@ -243,8 +243,8 @@ This key is optional.
 
 =item o password => $string
 
-Specifies the password (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the password (as used by
+DBI -> connect($data_source, $username, $password, $data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(password => $string).
 
@@ -288,8 +288,8 @@ This key is optional.
 
 =item o username => $string
 
-Specifies the username (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the username (as used by
+DBI -> connect($data_source, $username, $password, $data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(username => $string).
 
@@ -336,8 +336,8 @@ Returns 1.
 
 =head1 Method: traverse()
 
-Retrieves all ids from the sessions table, and for each id calls the supplied subroutine with the id as the only
-parameter.
+Retrieves all ids from the sessions table, and for each id calls the supplied subroutine with the id
+as the only parameter.
 
 Returns 1.
 
