@@ -7,7 +7,7 @@ use warnings;
 
 use Hash::FieldHash ':all';
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -102,8 +102,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -119,8 +119,8 @@ This key is optional.
 
 =item o data_source => $string
 
-Specifies the data source (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the data source (as used by DBI -> connect($data_source, $username, $password,
+$data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(data_source => $string).
 
@@ -182,8 +182,8 @@ This key is optional.
 
 =item o password => $string
 
-Specifies the password (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the password (as used by DBI -> connect($data_source, $username, $password,
+$data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(password => $string).
 
@@ -202,8 +202,9 @@ the call $dbh = DBI -> connect('dbi:mysql:database=test;port=5000', ...).
 
 Specifies the socket to attach to the data_source.
 
-So Data::Session -> new(data_source => 'dbi:mysql:database=test', socket => '/dev/mysql.sock') generates
-the call $dbh = DBI -> connect('dbi:mysql:database=test;mysql_socket=/dev/mysql.sock', ...).
+So Data::Session -> new(data_source => 'dbi:mysql:database=test', socket => '/dev/mysql.sock')
+generates the call
+$dbh = DBI -> connect('dbi:mysql:database=test;mysql_socket=/dev/mysql.sock', ...).
 
 The reason this key is called socket and not mysql_socket is in case other drivers permit a socket
 option.
@@ -220,8 +221,8 @@ This key is optional.
 
 =item o username => $string
 
-Specifies the username (as used by DBI -> connect($data_source, $username, $password, $data_source_attr) ) to
-obtain a database handle.
+Specifies the username (as used by
+DBI -> connect($data_source, $username, $password, $data_source_attr) ) to obtain a database handle.
 
 This key is normally passed in as Data::Session -> new(username => $string).
 
@@ -266,8 +267,8 @@ Returns 1.
 
 =head1 Method: traverse()
 
-Retrieves all ids from the sessions table, and for each id calls the supplied subroutine with the id as the only
-parameter.
+Retrieves all ids from the sessions table, and for each id calls the supplied subroutine with the id
+as the only parameter.
 
 $dbh -> selectall_arrayref is used, and the table is not locked.
 
