@@ -9,7 +9,7 @@ use Fcntl qw/:DEFAULT :flock/;
 
 use Hash::FieldHash ':all';
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -93,7 +93,8 @@ To use this module do this:
 
 =over 4
 
-=item o Specify an id generator of type AutoIncrement, as Data::Session -> new(type => '... id:AutoIncrement ...')
+=item o Specify an id generator of type AutoIncrement, as
+Data::Session -> new(type => '... id:AutoIncrement ...')
 
 =back
 
@@ -110,8 +111,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -155,8 +156,8 @@ This key is optional.
 
 =item o no_flock => $boolean
 
-Specifies (no_flock => 1) to not use flock() to obtain a lock on $file_name (which holds the 'current' id)
-before processing it, or (no_flock => 0) to use flock().
+Specifies (no_flock => 1) to not use flock() to obtain a lock on $file_name (which holds the
+'current' id) before processing it, or (no_flock => 0) to use flock().
 
 This key is normally passed in as Data::Session -> new(no_flock => $boolean).
 
