@@ -7,7 +7,7 @@ use warnings;
 
 use Hash::FieldHash ':all';
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -83,8 +83,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
@@ -112,7 +112,8 @@ This key is optional.
 
 =head1 Method: generate()
 
-Generates the next session id (which is always what was passed in to new(id => ...) ), or dies if it can't.
+Generates the next session id (which is always what was passed in to new(id => ...) ), or dies if it
+can't.
 
 Returns the new id.
 
