@@ -15,7 +15,7 @@ use vars qw( %overloaded );
 
 require overload;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -184,13 +184,15 @@ See L<Data::Session> for details.
 
 =head1 Description
 
-L<Data::Session::Serialize::DataDumper> allows L<Data::Session> to manipulate sessions with L<Data::Dumper>.
+L<Data::Session::Serialize::DataDumper> allows L<Data::Session> to manipulate sessions with
+L<Data::Dumper>.
 
 To use this module do this:
 
 =over 4
 
-=item o Specify a driver of type DataDumper as Data::Session -> new(type=> '... serialize:DataDumper')
+=item o Specify a driver of type DataDumper as
+Data::Session -> new(type=> '... serialize:DataDumper')
 
 =back
 
@@ -216,8 +218,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
