@@ -7,7 +7,7 @@ use warnings;
 
 use FreezeThaw;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -55,13 +55,15 @@ See L<Data::Session> for details.
 
 =head1 Description
 
-L<Data::Session::Serialize::FreezeThaw> allows L<Data::Session> to manipulate sessions with L<FreezeThaw>.
+L<Data::Session::Serialize::FreezeThaw> allows L<Data::Session> to manipulate sessions with
+L<FreezeThaw>.
 
 To use this module do this:
 
 =over 4
 
-=item o Specify a driver of type FreezeThaw as Data::Session -> new(type => '... serialize:FreezeThaw')
+=item o Specify a driver of type FreezeThaw as
+Data::Session -> new(type => '... serialize:FreezeThaw')
 
 =back
 
@@ -78,8 +80,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
