@@ -7,7 +7,7 @@ use warnings;
 
 use Storable;
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 
 # -----------------------------------------------
 
@@ -53,11 +53,13 @@ L<Data::Session::Serialize::Storable> - A persistent session manager
 
 See L<Data::Session> for details.
 
-Warning: Storable should be avoided until this problem is fixed: http://rt.cpan.org/Public/Bug/Display.html?id=36087
+Warning: Storable should be avoided until this problem is fixed:
+L<http://rt.cpan.org/Public/Bug/Display.html?id=36087>
 
 =head1 Description
 
-L<Data::Session::Serialize::Storable> allows L<Data::Session> to manipulate sessions with L<Storable>.
+L<Data::Session::Serialize::Storable> allows L<Data::Session> to manipulate sessions with
+L<Storable>.
 
 To use this module do this:
 
@@ -80,8 +82,8 @@ might be mandatory.
 
 The keys are listed here in alphabetical order.
 
-They are lower-case because they are (also) method names, meaning they can be called to set or get the value
-at any time.
+They are lower-case because they are (also) method names, meaning they can be called to set or get
+the value at any time.
 
 =over 4
 
